# Django Brazilian Addresses
[![Build Status](https://travis-ci.org/felipefrizzo/django-brazilian-addresses.svg?branch=master)](https://travis-ci.org/felipefrizzo/django-brazilian-addresses)  
A django client library for Brazilian Correios API's, current solution available to find addresses by zipcode, calculate the shipping service and tracking.

## How to develop ?
In progress...

## Installation
In progress...

## Author
This django library was created in 2018 by [Felipe Frizzo]('http://felipefrizzo.github.io')

## License
The MIT License (MIT)